# JAX-AM

<p align="middle">
  <img src="docs/materials/logo.png" width="200" />
</p>

A GPU-based simulation toolbox for additive manufacturing.

## Documentation

Please see the [web documentation](https://jax-am.readthedocs.io/en/latest/) for details of this project.
